@@ -2,8 +2,8 @@ from datetime import datetime
 from typing import Optional
 from urllib.parse import quote as sanitize_param
 
-from coiote.utils import ApiEndpoint, api_call
-from coiote.v3.model.device_monitoring import MonitoringStatus, MonitoringDataResponse, ISO_INSTANT_FORMAT
+from coiote.utils import ApiEndpoint, api_call, ISO_INSTANT_FORMAT
+from coiote.v3.model.device_monitoring import MonitoringStatus, MonitoringDataResponse
 
 
 class DeviceMonitoring(ApiEndpoint):
@@ -20,9 +20,7 @@ class DeviceMonitoring(ApiEndpoint):
     def get_data_batch(self, device_id: str, lwm2m_url: str, start_time: datetime, end_time: Optional[datetime],
                        limit=2048) -> MonitoringDataResponse:
         safe_lwm2m_url = sanitize_param(lwm2m_url, safe='')
-        params = {}
-        params["timeRangeStart"] = start_time.strftime(ISO_INSTANT_FORMAT)
-        params["limit"] = limit
+        params = {"timeRangeStart": start_time.strftime(ISO_INSTANT_FORMAT), "limit": limit}
         if end_time:
             params["timeRangeEnd"] = end_time.strftime(ISO_INSTANT_FORMAT)
         return self.session.get(
