@@ -1,7 +1,8 @@
-from typing import List
+from datetime import datetime
+from typing import List, Optional
 from urllib.parse import quote as sanitize_param
 
-from coiote.utils import ApiEndpoint, api_call
+from coiote.utils import ApiEndpoint, api_call, ISO_INSTANT_FORMAT
 from coiote.v3.model.task_reports import ExecutedTaskInfo, TaskReportBatch, TasksSummary, TaskReport
 
 
@@ -23,6 +24,24 @@ class TaskReports(ApiEndpoint):
     def get_next_reports_batch(self, cursor_id: int, count: int) -> TaskReportBatch:
         return self.session.get(super()._make_url("/moreReports"), params={"cursor": cursor_id, "count": count})
 
+    @api_call(TaskReport)
+    def find_reports_since(self,
+                           since: datetime,
+                           taskId: Optional[str] = None,
+                           deviceId: Optional[str] = None,
+                           limit: int = 512,
+                           polling_interval_seconds: Optional[int] = None,
+                           only_direct_tasks: bool = False) -> List[TaskReport]:
+        params = {
+            "lastUpdateTime": since.strftime(ISO_INSTANT_FORMAT),
+            "taskId": taskId,
+            "deviceId": deviceId,
+            "limit": limit,
+            "pollingInterval": polling_interval_seconds,
+            "directTasksOnly": only_direct_tasks
+        }
+        return self.session.get(super()._make_url("/findSince"), params=params)
+
     @api_call(TasksSummary)
     def get_task_summary(self, task_id: str) -> TasksSummary:
         return self.session.get(super()._make_url("/summary"), params={"taskId": task_id})
